function varargout = gyak4gui(varargin)
% GYAK4GUI M-file for gyak4gui.fig
%      GYAK4GUI, by itself, creates a new GYAK4GUI or raises the existing
%      singleton*.
%
%      H = GYAK4GUI returns the handle to a new GYAK4GUI or the handle to
%      the existing singleton*.
%
%      GYAK4GUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GYAK4GUI.M with the given input arguments.
%
%      GYAK4GUI('Property','Value',...) creates a new GYAK4GUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before gyak4gui_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to gyak4gui_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help gyak4gui

% Last Modified by GUIDE v2.5 19-Mar-2012 12:38:12

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gyak4gui_OpeningFcn, ...
                   'gui_OutputFcn',  @gyak4gui_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before gyak4gui is made visible.
function gyak4gui_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to gyak4gui (see VARARGIN)

% Choose default command line output for gyak4gui
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes gyak4gui wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = gyak4gui_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on slider movement.
function slider2_Callback(hObject, eventdata, handles)
% hObject    handle to slider2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider
m=get(handles.slider2, 'Value');
t0=[0 400];
x0=[0 1];
[t,y]=ode45(@(t,y)gyak4(t,y,m), t0,x0);
plot(y(:,1), y(:,2));



% --- Executes during object creation, after setting all properties.
function slider2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slider2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


